@@ -7,6 +7,8 @@ from motion.utils import (
 )
 from motion.instance import ComponentInstance
 from motion.migrate import StateMigrator
+from motion.dicts import MDataFrame
+from motion.copy_utils import copy_motion_db
 
 __all__ = [
     "Component",
@@ -16,4 +18,6 @@ __all__ = [
     "inspect_state",
     "StateMigrator",
     "get_instances",
+    "MDataFrame",
+    "copy_motion_db",
 ]
